diff --git a/slave variables documentation - Pregmod.txt b/slave variables documentation - Pregmod.txt
index f2b35ba2bc4766661e5aacb0ec0817a3aa32f209..178e02c8a92164f2d151ee6356e1c1b96dc766cc 100644
--- a/slave variables documentation - Pregmod.txt	
+++ b/slave variables documentation - Pregmod.txt	
@@ -2844,6 +2844,8 @@ pFace + uFace - Depends on carrier status, may swing between average and above/b
 
 albinism - slave has pale skin, white hair and red eyes
 
+heterochromia - slave may have mismatched eye colors (Takes a string if not zero!)
+
 rearLipedema - slave's ass never stops growing. Increased growth rate, reduced shrink rate.
 
 wellHung - slave has (or will have) a huge dong
diff --git a/src/js/generateGenetics.js b/src/js/generateGenetics.js
index e307acb3ee2f00c0895267ffa209a19ebfcb6925..0c25df36532a0a7f3aa6fa828a55787fff6897c5 100644
--- a/src/js/generateGenetics.js
+++ b/src/js/generateGenetics.js
@@ -520,7 +520,7 @@ window.generateGenetics = (function() {
 
 	// genetic quirks
 	function setGeneticQuirks(father, mother, sex) {
-		let quirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0};
+		let quirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, heterochromia: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0};
 		let chance = 0;
 
 		// fertility
diff --git a/src/pregmod/widgets/pregmodWidgets.tw b/src/pregmod/widgets/pregmodWidgets.tw
index b06b254d910516d259d147f5dd344f5bb7035771..d8e8311af124473bd999f29d101087894d9f02cb 100644
--- a/src/pregmod/widgets/pregmodWidgets.tw
+++ b/src/pregmod/widgets/pregmodWidgets.tw
@@ -1,7 +1,7 @@
 :: pregmod widgets [nobr widget]
 
 <<widget "initPC">>
-	<<set $PC = {name: "Anonymous", surname: 0, title: 1, ID: -1, genes: "XY", pronoun: "he", possessive: "him", object: "his", dick: 1, vagina: 0, preg: 0, pregType: 0, pregWeek: 0, pregKnown: 0, belly: 0, bellyPreg: 0, mpreg: 0, pregSource: 0, pregMood: 0, labor: 0, births: 0, boobsBonus: 0, degeneracy: 0, voiceImplant: 0, accent: 0, shoulders: 0, shouldersImplant: 0, boobs: 0, lactation: 0, lactationDuration: 0, career: "capitalist", rumor: "wealth", birthWeek: random(0,51), age: 2, sexualEnergy: 4, refreshment: "cigar", refreshmentType: 0, trading: 0, warfare: 0, slaving: 0, engineering: 0, medicine: 0, hacking: 0, cumTap: 0, race: "white", origRace: "white", skin: "white", origSkin: "white", markings: "none", eyeColor: "blue", origEye: "blue", pupil: "circular", sclerae: "white", hColor: "blonde", origHColor: "blonde", nationality: "Stateless", father: 0, mother: 0, sisters: 0, daughters: 0, birthElite: 0, birthMaster: 0, birthDegenerate: 0, birthClient: 0, birthOther: 0, birthArcOwner: 0, birthCitizen: 0, birthSelf: 0, birthLab: 0, slavesFathered: 0, slavesKnockedUp: 0, intelligence: 100, face: 100, faceShape: "normal", actualAge: 35, physicalAge: 35, visualAge: 35, boobsImplant: 0, butt: 0, buttImplant: 0, balls: 0, ballsImplant: 0, ageImplant: 0, newVag: 0, reservedChildren: 0, reservedChildrenNursery: 0, fertDrugs: 0, forcedFertDrugs: 0, staminaPills: 0, ovaryAge: 35, eggType: "human", ballType: "human", storedCum: 0, behavioralFlaw: "none", behavioralQuirk: "none", sexualFlaw: "none", sexualQuirk: "none", fetish: "none", pubicHStyle: "hairless", underArmHStyle: "hairless", geneticQuirks: {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0}}>>
+	<<set $PC = {name: "Anonymous", surname: 0, title: 1, ID: -1, genes: "XY", pronoun: "he", possessive: "him", object: "his", dick: 1, vagina: 0, preg: 0, pregType: 0, pregWeek: 0, pregKnown: 0, belly: 0, bellyPreg: 0, mpreg: 0, pregSource: 0, pregMood: 0, labor: 0, births: 0, boobsBonus: 0, degeneracy: 0, voiceImplant: 0, accent: 0, shoulders: 0, shouldersImplant: 0, boobs: 0, lactation: 0, lactationDuration: 0, career: "capitalist", rumor: "wealth", birthWeek: random(0,51), age: 2, sexualEnergy: 4, refreshment: "cigar", refreshmentType: 0, trading: 0, warfare: 0, slaving: 0, engineering: 0, medicine: 0, hacking: 0, cumTap: 0, race: "white", origRace: "white", skin: "white", origSkin: "white", markings: "none", eyeColor: "blue", origEye: "blue", pupil: "circular", sclerae: "white", hColor: "blonde", origHColor: "blonde", nationality: "Stateless", father: 0, mother: 0, sisters: 0, daughters: 0, birthElite: 0, birthMaster: 0, birthDegenerate: 0, birthClient: 0, birthOther: 0, birthArcOwner: 0, birthCitizen: 0, birthSelf: 0, birthLab: 0, slavesFathered: 0, slavesKnockedUp: 0, intelligence: 100, face: 100, faceShape: "normal", actualAge: 35, physicalAge: 35, visualAge: 35, boobsImplant: 0, butt: 0, buttImplant: 0, balls: 0, ballsImplant: 0, ageImplant: 0, newVag: 0, reservedChildren: 0, reservedChildrenNursery: 0, fertDrugs: 0, forcedFertDrugs: 0, staminaPills: 0, ovaryAge: 35, eggType: "human", ballType: "human", storedCum: 0, behavioralFlaw: "none", behavioralQuirk: "none", sexualFlaw: "none", sexualQuirk: "none", fetish: "none", pubicHStyle: "hairless", underArmHStyle: "hairless", geneticQuirks: {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, heterochromia: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0}}>>
 
 	<<set WombInit($PC)>>
 
@@ -10,7 +10,11 @@
 <<widget "PMODinit">>
 
 <<if ndef $args[0].geneticQuirks>> /* needed by WombInit() */
-	<<set $args[0].geneticQuirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0}>>
+	<<set $args[0].geneticQuirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, heterochromia: 0, rearLipedema: 0, wellHung: 0, wGain: 0, wLoss: 0, androgyny: 0}>>
+<<else>>
+	<<if ndef $args[0].geneticQuirks.heterochromia>>
+		<<set $args[0].geneticQuirks.heterochromia = 0>>
+	<</if>>
 <</if>>
 
 <<set WombInit($args[0])>>
diff --git a/src/uncategorized/BackwardsCompatibility.tw b/src/uncategorized/BackwardsCompatibility.tw
index 95bd960c17f821c111cf6684de7659216dffe84b..5ef87321b13a1f5a309ca4d822bc11308f06e950 100644
--- a/src/uncategorized/BackwardsCompatibility.tw
+++ b/src/uncategorized/BackwardsCompatibility.tw
@@ -385,12 +385,16 @@
 	<<set $PC.ballType = "human">>
 <</if>>
 <<if ndef $PC.geneticQuirks>>
-	<<set $PC.geneticQuirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, rearLipedema: 0, wellHung: 1, wGain: 0, wLoss: 0, androgyny: 0}>>
+	<<set $PC.geneticQuirks = {macromastia: 0, gigantomastia: 0, fertility: 0, hyperFertility: 0, superfetation: 0, gigantism: 0, dwarfism: 0, pFace: 0, uFace: 0, albinism: 0, heterochromia: 0, rearLipedema: 0, wellHung: 1, wGain: 0, wLoss: 0, androgyny: 0}>>
 	<<if $PC.birthMaster > 0>>
 		<<set $PC.geneticQuirks.fertility = 2>>
 	<<elseif $PC.career == "servant">>
 		<<set $PC.geneticQuirks.fertility = 1>>
 	<</if>>
+<<else>>
+	<<if ndef $PC.geneticQuirks.heterochromia>>
+		<<set $PC.geneticQuirks.heterochromia = 0>>
+	<</if>>
 <</if>>
 <<if $releaseID < 1032>>
 	<<if $PC.pregSource == -1>>
diff --git a/src/js/SlaveState.js b/src/js/SlaveState.js
index aa66d0a24b2e45f8b37d5453aba12184e065c9ed..987e6e92040221fb91f39e1ffe8c901c6ba7ea31 100644
--- a/src/js/SlaveState.js
+++ b/src/js/SlaveState.js
@@ -1732,7 +1732,9 @@ App.Entity.SlaveState = class SlaveState {
 		 * * "size queen": prefers big cocks
 		 */
 		this.sexualQuirk = "none";
 		/** 0: does not have; 1: carrier; 2: active */
 		this.geneticQuirks = {
 			/** Oversized breasts. Increased growth rate, reduced shrink rate. Breasts try to return to oversized state if reduced. */
 			macromastia: 0,
@@ -1756,8 +1758,10 @@ App.Entity.SlaveState = class SlaveState {
 			pFace: 0,
 			/** has a hideous face. pFace + uFace - Depends on carrier status, may swing between average and above/below depending on it */
 			uFace: 0,
-			/**  has pale skin, white hair and red eyes */
+			/** has pale skin, white hair and red eyes */
 			albinism: 0,
+			/** may have mismatched eyes */
+			heterochromia: 0,
 			/** ass never stops growing. Increased growth rate, reduced shrink rate. */
 			rearLipedema: 0,
 			/** has (or will have) a huge dong */
@@ -1732,7 +1732,9 @@ App.Entity.SlaveState = class SlaveState {
 		 */
 		this.sexualQuirk = "none";
-		/** 0: does not have; 1: carrier; 2: active */
+		/** 0: does not have; 1: carrier; 2: active 
+		* * heterochromia is an exception. String = active
+		*/
 		this.geneticQuirks = {
 			/** Oversized breasts. Increased growth rate, reduced shrink rate. Breasts try to return to oversized state if reduced. */